==> aria2-1.16.5.tar.bz2: aria2-1.16.5/src/MetadataInfo.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_METADATA_INFO_H
#define D_METADATA_INFO_H

#include "common.h"

#include <string>

#include "SharedHandle.h"
#include "GroupId.h"

namespace aria2 {

class MetadataInfo {
private:
  SharedHandle<GroupId> gid_;
  std::string uri_;
public:
  MetadataInfo(const SharedHandle<GroupId>& gid, const std::string& uri);

  MetadataInfo();

  ~MetadataInfo();

  bool dataOnly() const
  {
    return !gid_;
  }

  const std::string& getUri() const
  {
    return uri_;
  }

  a2_gid_t getGID() const
  {
    assert(gid_);
    return gid_->getNumericId();
  }
};

} // namespace aria2

#endif // D_METADATA_INFO_H

==> aria2_1.19.0.orig.tar.bz2: aria2-1.19.0/src/MetadataInfo.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_METADATA_INFO_H
#define D_METADATA_INFO_H

#include "common.h"

#include <string>
#include <memory>

#include "GroupId.h"

namespace aria2 {

class MetadataInfo {
private:
  std::shared_ptr<GroupId> gid_;
  std::string uri_;
public:
  MetadataInfo(const std::shared_ptr<GroupId>& gid, const std::string& uri);

  MetadataInfo();

  ~MetadataInfo();

  bool dataOnly() const
  {
    return !gid_;
  }

  const std::string& getUri() const
  {
    return uri_;
  }

  a2_gid_t getGID() const;
};

} // namespace aria2

#endif // D_METADATA_INFO_H
